[![Build Status](https://travis-ci.org/Viant-Metabolomics/msPurity.svg?branch=master)](https://travis-ci.org/Viant-Metabolomics/msPurity) [![Build Status windows](https://ci.appveyor.com/api/projects/status/github/viant-metabolomics/mspurity?branch=master&svg=true)](https://ci.appveyor.com/project/tomnl/mspurity/)

Continuous integration tests above are for travis and AppVeyor 


# msPurity

## About
The importance of assessing the contribution of the precursor peak within an isolation window targeted for fragmentation has been previously detailed in proteomics but to date there has been little attention of this data-processing technique in metabolomics. Here we present msPurity, a vendor independent R package for Liquid Chromatography-Mass spectrometry (LC-MS) and Direct Infusion-Mass Spectrometry (DI-MS) that calculates a simple metric to describe the contribution of the selected precursor peak. What we call "Precursor purity" is a measure of the contribution of a selected precursor peak in an isolation window used for fragmentation. The simple calculation involves dividing the intensity of the selected precursor peak by the total intensity of the isolation window. When assessing MS/MS spectra this calculation is done before and after the MS/MS scan of interest and the purity is interpolated at the recorded time of the MS/MS acquisition. The calculation is similar to the "Precursor Ion Fraction" (PIF) metric described by  \[1\] for proteomics with the exception that metric here is interpolated at the recorded point of MS2 acquisition using bordering full-scan spectra, low abundance peaks are removed that are thought to have limited contribution to the resulting MS2 spectra and the isolation efficiency of the mass spectrometer can be considered in the calculation.

Use the following link for more details:

* Bioconductor: http://bioconductor.org/packages/msPurity/
* Vignette: https://bioconductor.org/packages/devel/bioc/vignettes/msPurity/inst/doc/msPurity-vignette.html
* Manual: http://bioconductor.org/packages/devel/bioc/manuals/msPurity/man/msPurity.pdf


## Install


### Github

```

library(devtools)
library(testthat)

t <- try(install_github('Viant-Metabolomics/msPurity'))

if("try-error" %in% class(t)){
  print("INSTALLATION FAILED!")
} else {
  print("INSTALLATION SUCCESS!")
  print("PERFORM UNIT TESTING")
  # Perform unit test to make sure the package is working as expected
  tp <- test_package('msPurity')
  print(tp)
}
```

### Bioconductor

```
## try http:// if https:// URLs are not supported
source("https://bioconductor.org/biocLite.R")
# NOTE: Currently only available in development branch (it is advised to have seperate install of
#       R when using the development branch, see https://www.bioconductor.org/developers/how-to/useDevel/)
useDevel() 
biocLite("msPurity")

```



## Ref
[1] Michalski, A., Cox, J., & Mann, M. (2011). More than 100,000 detectable peptide species elute in single shotgun proteomics runs but the majority is inaccessible to data-dependent LC-MS/MS. Journal of Proteome Research, 10(4), pp. 1785-1793.



